from cpistats import anderson_darling_normality


def test_anderson_darling_normality():

    data = [12.4, 13.1, 12.9, 13.5, 12.8, 13.0, 12.7, 13.2]

    result = anderson_darling_normality(data)

    assert round(result.mean, 2) == 12.95
    assert result.sample_size == 8
    assert result.p_value > 0